@@ -7,8 +7,7 @@ from flowtool.execute import run_command
 from flowtool.style import debug
 
 from flowtool_git.common import local_repo, local_git_command
-#from flowtool_git.common import short_status
-from flowtool_git.common import dirty_files
+from flowtool_git.common import short_status
 from flowtool_git.config import getconfig_simple
 
 #from pylint.lint import Run
@@ -188,39 +187,67 @@ def find_project_py_files(repo, ignore_dirs=frozenset(['.git', 'build', 'dist',
     return result
 
 
-def discover_lint_files(repo=None):
-    """ Return the list of dirty py files in the git. """
 
-    return [f for f in dirty_files() if f.endswith('.py')]
+def added_files(suffix='', untracked_files=False):
+    """ Return the list of files that match suffix and are added
+        to the local git's index.
+    """
+    untracked = 'yes' if untracked_files else 'no'
+    added = []
+    for line in short_status('--untracked-files=%s' % untracked):
+        if line.on_index != ' ':
+            added.append(line.filename)
+    return [f for f in added if f.endswith(suffix)]
 
 
-
-def pylint_minimal(*args, **kwd):
-    """ Run pylint with a minimal config. """
+@click.command()
+@click.argument('args', nargs=-1)
+def pylint_minimal(args=()):
+    """ Run pylint with on all files added to the commit.
+        This does just check the files in the repo, so if
+        has changes not added to the index, the file checked
+        may not be the same as the file checked in.
+    """
     repo = local_repo()
     cfg = get_config_name(repo)
     if not os.path.isfile(cfg):
         pylint_setup('install')
-    check_these = discover_lint_files(repo)
+    check_these = added_files('.py')
     if check_these:
         run_hook(check_these, cfg)
 
 
-def discover_changed_files(repo=None):
-    """ Return the list of files to check (on pre-push). """
+def discover_changed_files(
+        suffix='',
+        reference_branch='origin/master',
+        diff_filter='D',
+    ):
+    """ Return the list of files that match suffix and have changes
+        in comparison to the reference_branch.
 
-    reference_branch = 'origin/master'
+        diff_filter maps to the --diff-filter option of `git diff`:
 
-    if repo is None:
-        repo = local_repo()
+        Select only files that are Added (A), Copied (C), Deleted (D),
+        Modified (M), Renamed (R), have their type (i.e. regular file, symlink,
+        submodule, ...) changed (T), are Unmerged (U), are Unknown (X), or have
+        had their pairing Broken (B).
+    """
 
-    changed = repo.git.diff('--name-status', reference_branch).split('\n')
-    result = [l.split('\t', 1) for l in changed if l]
+    repo = local_repo()
+    changed = repo.git.diff(
+        '--name-status',
+        '--diff-filter=%s' % diff_filter,
+        reference_branch,
+    ).split('\n')
+    parsed = [l.split('\t', 1) for l in changed if l]
 
-    return [f[1] for f in result if f[0] != 'D' and f[1].endswith('.py')]
+    return [f[1] for f in parsed if f[1].endswith(suffix)]
 
 
-def pylint_pre_push(*args, **kwd):
+@click.command()
+@click.argument('remote', nargs=1)
+@click.argument('address', nargs=1)
+def pylint_pre_push(remote='', address=''):
     """ Run pylint with a minimal config. """
 
     repo = local_repo()
@@ -228,6 +255,6 @@ def pylint_pre_push(*args, **kwd):
     if not os.path.isfile(cfg):
         pylint_setup('install')
 
-    check_these = discover_changed_files(repo)
+    check_these = discover_changed_files('.py')
     if check_these:
         run_hook(check_these, cfg)
